#!perl -w

system ('cls');
#system ('clear');

print "\n*********************************
\nThis script reformats OTU listings as output in 
the '.list' file from MOTHUR or DOTUR and 
returns a list of representative sequences for each OTU.\n

by Brian Oakley
b.b.c.oakley at warwick.ac.uk
*********************************\n";

print "\n
To use:\n
1)  Put the MOTHUR (or DOTUR) output file that ends with '.list' 
in the same directory as this script\n

Enter file name of '.list' file...  ";
chomp (my $input_file = <STDIN>);

print "\nEnter desired OTU definitions singly (e.g. 0.03) or in multiples seperated by spaces (e.g. 0.01 0.03 0.05): ";
chomp (my $sim_cutoffs = <STDIN>);
my @sim_cutoffs = split(/\s/, $sim_cutoffs);

print "\nEnter desired number of representative sequences for each OTU...  ";
chomp (my $num_reps = <STDIN>);

open (OUT, ">OTU_representative_seqs.txt") or die "\n\nLooks like output file might be open.  Close and try again\n\n";
open (OUT1, ">all_seqs.txt") or die "\n\nLooks like output file might be open.  Close and try again\n\n";

#----open MOTHUR/DOTUR file---
open (INPUT, $input_file);
chomp (my @mothur_input = <INPUT>);

#----Print column headings to STDOUT and to output files-----
print "\nLooking for following OTU definitions:\n
	   \nOTU\t\tOTUs_PRESENT\t\tOTUs_FOUND\n\n";
print OUT ("Seq_ID\tOTU_cutoff\tOTU\tOTU_membership\n");
print OUT1 ("Seq_ID\tOTU_cutoff\tOTU\tOTU_membership\n");

#---Search for each OTU definition in turn---
foreach $sim_cutoff(@sim_cutoffs) {

#--Empty data each time through loop---
my @each_OTU=();
my $num_of_OTUs=0;
	
#---push data into new array called @each_OTU---
	foreach $line(@mothur_input) {
	$line=~s/\n//;
	@OTU_table=split (/\t/, $line);
		if ($OTU_table[0] eq $sim_cutoff) {
		$num_of_OTUs = $OTU_table[1];
		my $n=0;
		while ($n<$num_of_OTUs) {
		push (@each_OTU, $OTU_table[$n+2]);
		$n++;
		}
		}	
	}

#----Print OTU definition and num of seqs found to STDOUT -----
	print $sim_cutoff,"\t\t",$num_of_OTUs,"\t\t\t",scalar(@each_OTU),"\n\n";

#---Return error if particular cutoff is not found---
	if ($num_of_OTUs==0) { 
	print "\nLooks like you have zero values encountered for some of your OTU definitions.  Check the '.list' file and make sure that value is present and the syntax matches exactly.  If the value is not present, use the preceding lesser value.\n\n";
	}

#---split and print sequences---
$OTU_counter=0;
foreach $each_OTU (@each_OTU) {
	$OTU_counter+=1;
	@OTU_members = split (/,/, $each_OTU);
	$membership = scalar(@OTU_members);
	
	#print output for representative seqs (just the first $num_reps in the list)
		my $n=0;
		while ($n<$num_reps) {
		$n++;
		if (defined $OTU_members[$n-1]) {
		print OUT ($OTU_members[$n-1],"\t",$sim_cutoff,"\t",$OTU_counter,"\t",$membership,"\n");
		}
		}
		
	#print output for all seqs
		foreach $seq_ID(@OTU_members) {
		print OUT1 ("$seq_ID\t$sim_cutoff\t$OTU_counter\t$membership\n");
		}
}
}

print "\nDone.  Reformatted data written to \"all_seqs.txt\" and \"OTU_representative_seqs.txt\"\n\n";

close (OUT);

